@@ -175,8 +175,8 @@ class Aphantasia(ImageGenerator):
 
     def get_random_latents(
         self,
-        height: int,
-        width: int,
+        target_img_height: int,
+        target_img_width: int,
         batch_size: int = 1,
         std: float = 0.01,
     ) -> torch.Tensor:
@@ -186,7 +186,7 @@ class Aphantasia(ImageGenerator):
         it also return the image frequencies.
 
         Args:
-            height (int): height of the final image.
+            target_img_height (int): height of the final image.
             width (int): width of the final image.
             batch_size (int, optional): batch size of the resulting 
                 tensor. Defaults to 1.
@@ -204,8 +204,8 @@ class Aphantasia(ImageGenerator):
         """
         #NOTE: generat all possible freqs for the input image size
         img_freqs = self.compute_2d_img_freqs(
-            height=height,
-            width=width,
+            height=target_img_height,
+            width=target_img_width,
         )
 
         spectrum_shape = [
